# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system

Self = typing.TypeVar('Self')

class CustomXamlResourceLoader_Static(winrt._winrt.IInspectable_Static):
    # Windows.UI.Xaml.Resources.CustomXamlResourceLoader Windows.UI.Xaml.Resources.CustomXamlResourceLoader::get_Current()
    @_property
    def current(cls) -> CustomXamlResourceLoader: ...
    # System.Void Windows.UI.Xaml.Resources.CustomXamlResourceLoader::put_Current(Windows.UI.Xaml.Resources.CustomXamlResourceLoader)
    @current.setter
    @typing.final
    def current(cls, value: CustomXamlResourceLoader) -> None: ...

class CustomXamlResourceLoader(winrt.system.Object, metaclass=CustomXamlResourceLoader_Static):
    def __new__(cls: typing.Type[Self]) -> Self: ...
    # System.Object Windows.UI.Xaml.Resources.CustomXamlResourceLoader::GetResource(System.String,System.String,System.String,System.String)
    def _get_resource(self, resource_id: str, object_type: str, property_name: str, property_type: str, /) -> winrt.system.Object: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import winrt.system
from winrt._winrt_windows_ui_xaml_resources import (
    CustomXamlResourceLoader,
)
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from winrt._winrt_windows_ui_xaml_resources import (
        CustomXamlResourceLoader_Static,
    )

__all__ = [
    "CustomXamlResourceLoader",
]

